@@ -1,7 +1,7 @@
 package TableData::Object::aos;
 
-our $DATE = '2019-01-16'; # DATE
-our $VERSION = '0.110'; # VERSION
+our $DATE = '2019-09-15'; # DATE
+our $VERSION = '0.111'; # VERSION
 
 use 5.010001;
 use strict;
@@ -23,6 +23,11 @@ sub row_count {
     scalar @{ $self->{data} };
 }
 
+sub rows {
+    my $self = shift;
+    $self->{data};
+}
+
 sub rows_as_aoaos {
     my $self = shift;
     [map {[$_]} @{ $self->{data} }];
@@ -117,7 +122,7 @@ TableData::Object::aos - Manipulate array of scalars via table object
 
 =head1 VERSION
 
-This document describes version 0.110 of TableData::Object::aos (from Perl distribution TableData-Object), released on 2019-01-16.
+This document describes version 0.111 of TableData::Object::aos (from Perl distribution TableData-Object), released on 2019-09-15.
 
 =head1 SYNOPSIS
 
